@@ -2,6 +2,7 @@ package Net::Twitter;
 use Moose;
 use Carp;
 use Net::Twitter::Core;
+use Digest::SHA1 qw/sha1_hex/;
 
 use namespace::autoclean;
 
@@ -11,7 +12,7 @@ has '_trait_namespace' => (
 );
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.13008_02';
+our $VERSION = '3.16000_1';
 
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
@@ -21,7 +22,7 @@ $VERSION = eval $VERSION; # numify for warning-free dev releases
 # with the 'Legacy' trait.
 
 # transform_trait and resolve_traits stolen from MooseX::Traits
-my $transform_trait = sub {
+sub _transform_trait {
     my ($class, $name) = @_;
     my $namespace = $class->meta->find_attribute_by_name('_trait_namespace');
     my $base;
@@ -35,39 +36,63 @@ my $transform_trait = sub {
     return $name unless $base;
     return $1 if $name =~ /^[+](.+)$/;
     return "$base\::$name";
-};
+}
 
-my $resolve_traits = sub {
+sub _resolve_traits {
     my ($class, @traits) = @_;
-    return map {
-        my $transformed = $class->$transform_trait($_);
-        Class::MOP::load_class($transformed);
-        $transformed;
-    } @traits;
-};
 
-my $isa = sub {
+    return map {
+        unless ( ref ) {
+            $_ = $class->_transform_trait($_);
+            Class::MOP::load_class($_);
+        }
+        $_;
+    } @traits;
+}
+
+sub _isa {
     my $self = shift;
     my $isa  = shift;
 
     return $isa eq __PACKAGE__ || $self->SUPER::isa($isa)
 };
 
-my $create_anon_class = sub {
+sub _create_anon_class {
     my ($superclasses, $traits, $immutable, $package) = @_;
 
+    # Do we already have a meta class?
+    return $package->meta if $package->can('meta');
+
     my $meta;
     $meta = Net::Twitter::Core->meta->create_anon_class(
         superclasses => $superclasses,
         roles        => $traits,
-        methods      => { meta => sub { $meta }, isa => $isa },
+        methods      => { meta => sub { $meta }, isa => \&_isa },
         cache        => 1,
         package      => $package,
     );
     $meta->make_immutable(inline_constructor => $immutable);
 
     return $meta;
-};
+}
+
+sub _name_for_anon_class {
+    my @t = @{$_[0]};
+
+    my @comps;
+    while ( @t ) {
+        my $t = shift @t;
+        if ( ref $t[0] eq 'HASH' ) {
+            my $r = shift @t;
+            my $sig = sha1_hex(JSON::Any->to_json($r));
+            $t .= "_$sig";
+        }
+        $t =~ s/(?:::|\W)/_/g;
+        push @comps, $t;
+    }
+
+    return join '', __PACKAGE__, '::',  join '__', 'with', sort @comps;
+}
 
 sub new {
     my $class = shift;
@@ -87,13 +112,16 @@ sub new {
 
     $traits ||= [ qw/Legacy/ ];
 
-    my $package_suffix = 'with__' . join '__',
-       map { (my $part = $_) =~ s/::/_/g; $part =~ s/\W//; $part } sort @$traits;
+    # ensure we have the OAuth trait if we have a consumer key
+    $traits = [ (grep $_ ne 'OAuth', @$traits), 'OAuth' ] if $args{consumer_key};
 
-    $traits = [ $class->$resolve_traits(@$traits) ];
+    # create a unique name for the created class based on trait names and parameters
+    my $anon_class_name = _name_for_anon_class($traits);
+
+    $traits = [ $class->_resolve_traits(@$traits) ];
 
     my $superclasses = [ 'Net::Twitter::Core' ];
-    my $meta = $create_anon_class->($superclasses, $traits, 1, __PACKAGE__ . '::' . $package_suffix);
+    my $meta = _create_anon_class($superclasses, $traits, 1, $anon_class_name);
 
     # create a Net::Twitter::Core object with roles applied
     my $new = $meta->name->new(%args);
@@ -101,8 +129,8 @@ sub new {
     # rebless it to include a superclass, if we're being subclassed
     if ( $class ne __PACKAGE__ ) {
         unshift @$superclasses, $class;
-        my $final_meta = $create_anon_class->(
-            $superclasses, $traits, 0, join '::', $class, __PACKAGE__, $package_suffix
+        my $final_meta = _create_anon_class(
+            $superclasses, $traits, 0, join '::', $class, $anon_class_name
         );
         bless $new, $final_meta->name;
     }
