@@ -13,11 +13,12 @@ use HTML::Entities ();
 use Encode qw/encode_utf8/;
 use DateTime;
 use Data::Visitor::Callback;
+use Try::Tiny;
 
 use namespace::autoclean;
 
 # use *all* digits for fBSD ports
-our $VERSION = '3.13008_02';
+our $VERSION = '3.16000_1';
 
 $VERSION = eval $VERSION; # numify for warning-free dev releases
 
@@ -59,6 +60,31 @@ sub _extract_synthetic_args {
     return $synthetic_args;
 }
 
+around BUILDARGS => sub {
+    my $next    = shift;
+    my $class   = shift;
+
+    my %options = @_ == 1 ? %{$_[0]} : @_;
+
+    if ( delete $options{identica} ) {
+        %options = (
+            apiurl => 'http://identi.ca/api',
+            searchapiurl => 'http://identi.ca/api',
+            apirealm => 'Laconica API',
+            oauth_urls => {
+                request_token_url  => "https://identi.ca/api/oauth/request_token",
+                authentication_url => "https://identi.ca/api/oauth/authenticate",
+                authorization_url  => "https://identi.ca/api/oauth/authorize",
+                access_token_url   => "https://identi.ca/api/oauth/access_token",
+                xauth_url          => "https://identi.ca/api/oauth/access_token",
+            },
+            %options,
+        );
+    }
+
+    return $next->($class, \%options);
+};
+
 sub BUILD {
     my $self = shift;
 
@@ -116,11 +142,10 @@ sub _encode_args {
 sub _json_request { 
     my ($self, $http_method, $uri, $args, $authenticate, $synthetic_args, $dt_parser) = @_;
     
-    return $self->_parse_result(
-        $self->_prepare_request($http_method, $uri, $args, $authenticate),
-        $synthetic_args,
-        $dt_parser,
-    );
+    my $msg = $self->_prepare_request($http_method, $uri, $args, $authenticate);
+    my $res = $self->_send_request($msg);
+
+    return $self->_parse_result($res, $synthetic_args, $dt_parser);
 }
 
 sub _prepare_request {
@@ -150,7 +175,7 @@ sub _prepare_request {
 
     $self->_add_authorization_header($msg, $args) if $authenticate;
 
-    return $self->_send_request($msg);
+    return $msg;
 }
 
 # Basic Auth, overridden by Role::OAuth, if included
@@ -191,7 +216,7 @@ sub _parse_result {
     my $content = $res->content;
     $content =~ s/^"(true|false)"$/$1/;
 
-    my $obj = eval { $self->_from_json($content) };
+    my $obj = try { $self->_from_json($content) };
     $self->_decode_html_entities($obj) if $obj && $self->decode_html_entities;
 
     # filter before inflating objects
